@@ -1,15 +1,13 @@
 import os
-from uuid import uuid4
-
-import semver
 from contextlib import contextmanager
 from dataclasses import dataclass
 from typing import TYPE_CHECKING, List, Optional, Dict
+from uuid import uuid4
 
 import orjson
 import rocksdb
+import semver
 from loguru import logger
-from functools import cached_property
 
 from pbt.config import PBTConfig
 from pbt.git import Git, GitFileStatus
@@ -17,6 +15,11 @@ from pbt.git import Git, GitFileStatus
 if TYPE_CHECKING:
     from pbt.package import Package
 
+try:
+    from functools import cached_property
+except ImportError:
+    from cached_property import cached_property
+
 # file size limit
 SOFT_SIZE_LIMIT = (1024 ** 2) * 1  # 1MB
 HARD_SIZE_LIMIT = (1024 ** 2) * 100  # 100MBs
