@@ -4,7 +4,7 @@ import subprocess
 import tarfile
 from dataclasses import dataclass
 from enum import Enum
-from functools import cached_property
+
 from glob import glob
 from operator import attrgetter
 
@@ -21,6 +21,11 @@ from pbt.diff import diff_db, Diff
 from pbt.poetry import Poetry
 from pbt.version import parse_version
 
+try:
+    from functools import cached_property
+except ImportError:
+    from cached_property import cached_property
+
 
 class PackageType(str, Enum):
     Poetry = "poetry"
