@@ -1,20 +1,21 @@
-from functools import cached_property
 import os
 import re
 import subprocess
 from contextlib import contextmanager
-
-import sys
 from pathlib import Path
-from typing import Union, TYPE_CHECKING, List, Literal, Optional
+from typing import TYPE_CHECKING, List, Literal, Optional
 
 import semver
-import toml
 from loguru import logger
 
 if TYPE_CHECKING:
     from pbt.package import Package
 
+try:
+    from functools import cached_property
+except ImportError:
+    from cached_property import cached_property
+
 
 class Poetry:
     def __init__(self, package: "Package"):
